@@ -67,7 +67,7 @@ static void put_msg(char *buf, uint16_t i, int seq)
 
 static int cb_err(const struct nlmsghdr *nlh, void *data)
 {
-	struct nlmsgerr *err = (void *)(nlh + 1);
+	struct nlmsgerr *err = mnl_nlmsg_get_payload(nlh);
 	if (err->error != 0)
 		printf("message with seq %u has failed: %s\n",
 			nlh->nlmsg_seq, strerror(-err->error));
@@ -87,7 +87,7 @@ send_batch(struct mnl_socket *nl, struct mnl_nlmsg_batch *b, int portid)
 
 	ret = mnl_socket_sendto(nl, mnl_nlmsg_batch_head(b), len);
 	if (ret == -1) {
-		perror("mnl_socket_recvfrom");
+		perror("mnl_socket_sendto");
 		exit(EXIT_FAILURE);
 	}
 
@@ -116,7 +116,7 @@ send_batch(struct mnl_socket *nl, struct mnl_nlmsg_batch *b, int portid)
 				  NULL, NULL, cb_ctl_array,
 				  MNL_ARRAY_SIZE(cb_ctl_array));
 		if (ret == -1) {
-			perror("mnl_cb_run");
+			perror("mnl_cb_run2");
 			exit(EXIT_FAILURE);
 		}
 
